summaryrefslogtreecommitdiffhomepage
path: root/digital/io-hub/src/robospierre/element.h
diff options
context:
space:
mode:
authorJérôme Jutteau2011-06-02 00:20:21 +0200
committerJérôme Jutteau2011-06-02 00:36:45 +0200
commit056acc0205213f1aa5263ad8243aec55e38fb0bf (patch)
tree036646e56f2d67ac556088bfb59bc980d284942e /digital/io-hub/src/robospierre/element.h
parentf78f32f27a922a9c33e0592d9287d76eddedcb57 (diff)
digital/io-hub: change bonus for load and unload and adapt some scores
Diffstat (limited to 'digital/io-hub/src/robospierre/element.h')
-rw-r--r--digital/io-hub/src/robospierre/element.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/digital/io-hub/src/robospierre/element.h b/digital/io-hub/src/robospierre/element.h
index a31d9f4d..5a15f6b0 100644
--- a/digital/io-hub/src/robospierre/element.h
+++ b/digital/io-hub/src/robospierre/element.h
@@ -90,8 +90,11 @@ struct element_t
vect_t pos;
/** Emplacement attributes. */
uint8_t attr;
- /** Bonus coefficient (or Mallus if negative). */
- int8_t bonus;
+ /** Bonus coefficient (or Mallus if negative) for load scores. */
+ int8_t bonus_load;
+ /** Bonus coefficient (or Mallus if negative) for unload scores. */
+ int8_t bonus_unload;
+
};
typedef struct element_t element_t;